@@ -68,12 +68,15 @@ class TemplateSync:
         self.repo_owner = self.gh_username
         self.new_template_version = new_template_version
         self.github = Github(self.token)
+        self.blacklisted_globs = []
 
     def sync(self):
         """
         Sync the mlf-core project
         """
         self.inspect_sync_dir()
+        # get blacklisted files on current working branch
+        self.blacklisted_globs = self.get_blacklisted_sync_globs()
         self.checkout_template_branch()
         self.delete_template_branch_files()
         self.make_template_project()
@@ -197,9 +200,8 @@ class TemplateSync:
             self.repo.git.add(A=True)
             # get all changed/modified files during the sync (including blacklisted ones)
             changed_files = [item.a_path for item in self.repo.index.diff('HEAD')]
-            globs = self.get_blacklisted_sync_globs()
             blacklisted_changed_files = set()
-            for pattern in globs:
+            for pattern in self.blacklisted_globs:
                 # keep track of all staged files matching a glob from the mlf_core.cfg file
                 # those files will be excluded from syncing but will still be available in every new created projects
                 blacklisted_changed_files |= {file for file in fnmatch.filter(changed_files, pattern)}
